Learn R Programming

Runuran (version 0.41)

udexp: UNU.RAN object for Exponential distribution

Description

Create UNU.RAN object for an Exponential distribution with rate rate (i.e., mean 1/rate).

[Distribution] -- Exponential.

Usage

udexp(rate=1, lb=0, ub=Inf)

Value

An object of class "unuran.cont".

Arguments

rate

(strictly positive) rate parameter.

lb

lower bound of (truncated) distribution.

ub

upper bound of (truncated) distribution.

Author

Josef Leydold and Wolfgang H\"ormann [email protected].

Details

The Exponential distribution with rate \(\lambda\) has density $$ f(x) = \lambda {e}^{- \lambda x} $$ for \(x \ge 0\).

The domain of the distribution can be truncated to the interval (lb,ub).

References

N.L. Johnson, S. Kotz, and N. Balakrishnan (1994): Continuous Univariate Distributions, Volume 1. 2nd edition, John Wiley & Sons, Inc., New York. Chap. 19, p. 494.

See Also

unuran.cont.

Examples

Run this code
## Create distribution object for standard exponential distribution
distr <- udexp()
## Generate generator object; use method PINV (inversion)
gen <- pinvd.new(distr)
## Draw a sample of size 100
x <- ur(gen,100)

Run the code above in your browser using DataLab