unuran provides an interface to the UNU.RAN
library for universal non-uniform random number generators.
It uses the Rbuilt-in uniform random number generator.
[Advanced] -- UNU.RAN generator object.unuran.newunuran objects cannot be saved and restored in later Rsessions, nor is it possible to copy such objects to different nodes
in a computer cluster. However, unuran objects for some generation methods can be
unuran.packed.
Then these objects can be handled like any other Robject
(and thus saved and restored).
All other objects must be newly created in a new Rsession!
(Using a restored object does not work as the unuran is then
broken.)
G. Tirler and J. Leydold (2003): Automatic Nonuniform Random Variate Generation in R. In: K. Hornik and F. Leisch, Proceedings of the 3rd International Workshop on Distributed Statistical Computing (DSC 2003), March 20--22, Vienna, Austria.
unuran.new and ur for faster creation and
sampling routines, unuran.details for a more verbose
version of show. unuran.packed allows to pack some unuran
objects.
For distribution objects see ,
, and .