Learn R Programming

Runuran (version 0.10.1)

unuran.cont: Create a UNU.RAN distribution objects

Description

Create a new UNU.RAN object for distribution. [ Deprecated! ]

Usage

unuran.cmv(dim=1, pdf=NULL, mode=NULL, center=NULL, ll=NULL, ur=NULL)

unuran.cont(cdf=NULL, pdf=NULL, dpdf=NULL, islog=TRUE, mode=NA, center=NA, lb=-Inf, ub=Inf, area=NA)

unuran.discr(pv=NULL, pmf=NULL, mode=NA, lb=0, ub=Inf, sum=NA)

Arguments

dim
number of dimensions of the distribution. (integer)
cdf
cumulative distribution function. (Rfunction)
pdf
probability density function. (Rfunction)
dpdf
derivative of the pdf. (Rfunction)
pv
probability vector. (numeric vector)
pmf
probability mass function. (Rfunction)
ll,ur
lower left and upper right vertex of a rectangular domain of the pdf. The domain is only set if both vertices are not NULL. Otherwise, the domain is unbounded by default. (numeric vectors)
lb, ub
lower and upper bound of domain. (numeric)
islog
whether the given cdf and pdf are given by their logarithms (the dpdf is then the derivative of the logarithm). (boolean)
mode
mode of distribution. (numeric)
center
typical point (center) of distribution. If not given the mode is used. (numeric)
area
area below pdf; used for computing normalization constants if required. (numeric)
sum
sum over pv / pmf; used for computing normalization constants if required. (numeric)

Details

Creates an instance of class unuran.distr. These functions are deprecated. Use respective functions unuran.cmv.new, unuran.cont.new, and unuran.discr.new.

References

W. H"ormann, J. Leydold, and G. Derflinger (2004): Automatic Nonuniform Random Variate Generation. Springer-Verlag, Berlin Heidelberg.

See Also

unuran.cmv, unuran.cont, unuran.discr, unuran.distr.