Learn R Programming

Runuran (version 0.7.1)

unuran.details: Information on a given UNU.RAN generator object

Description

Prints type of UNU.RAN generator, data used from distribution, parameter for algorithm, performance characteristic, and hints to adjust the performance of the generator.

Usage

unuran.details(unur)

Arguments

unur
an "unuran" object.

See Also

unuran.