Learn R Programming

Runuran (version 0.5)

urgeom: UNU.RAN Geometric random variate generator

Description

UNU.RAN random variate generator for the Geometric distribution with parameter prob. It also allows sampling from the truncated distribution.

Usage

urgeom(n, prob, lb = 0, ub = Inf)

Arguments

n
size of required sample.
prob
probability of success in each trial. 0 < prob <= 1<="" code="">.
lb
lower bound of (truncated) distribution.
ub
upper bound of (truncated) distribution.

Details

The Geometric distribution with prob $= p$ has density $$p(x) = p {(1-p)}^{x}$$ for $x = 0, 1, 2, \ldots$, $0 < p \le 1$.

The generation algorithm uses guide table based inversion for $p > 0.02$ and method @code{"DARI"} otherwise. The parameters lb and ub can be used to generate variates from the Geometric distribution truncated to the interval (lb,ub).

References

W. H"ormann, J. Leydold, and G. Derflinger (2004): Automatic Nonuniform Random Variate Generation. Springer-Verlag, Berlin Heidelberg

See Also

runif and .Random.seed about random number generation, unuran for the UNU.RAN class, and rgeom for the Rbuilt-in generator.

Examples

Run this code
## Create a sample of size 1000
x <- urgeom(n=1000,prob=0.2)

Run the code above in your browser using DataLab