Learn R Programming

Runuran (version 0.10.1)

urhitro: UNU.RAN transformend density rejection generator

Description

UNU.RAN random variate generator for continuous multivariate distributions with given probability density function (PDF). It is based on the Hit-and-Run algorithm in combinaton with the Ratio-of-Uniforms method (HITRO). [ Deprecated. Use hitro.new instead. ]

Usage

urhitro(n, dim=1, pdf, mode=NULL, center=NULL, ll=NULL, ur=NULL, thinning=1, burnin = 0, ...)

Arguments

n
size of required sample.
dim
number of dimensions of the distribution. (integer)
pdf
probability density function. (Rfunction)
mode
location of the mode -- optional. (numeric vector)
center
point in typical region of distribution, e.g. the approximate location of the mode. If omitted the mode is implicitly used. If the mode is not given either, the origin is used. (numeric vector -- opti
ll,ur
lower left and upper right vertex of a rectangular domain of the pdf. The domain is only set if both vertices are not NULL. Otherwise, the domain is unbounded by default. (numeric vectors)
thinning
thinning factor. (positive integer)
burnin
lenght of burin-in phase. (positive integer)
...
(optional) arguments for pdf

Details

This method is deprecated. Please use hitro.new together with ur instead. For further details see hitro.new.

References

R. Karawatzki, J. Leydold, and K. P"otzelberger (2005): Automatic Markov Chain Monte Carlo Procedures for Sampling from Multivariate Distributions. Research Report Series / Department of Statistics and Mathematics, Nr. 27, December 2005 Department of Statistics and Mathematics, Wien, Wirtschaftsuniv., 2005. http://epub.wu-wien.ac.at/dyn/virlib/wp/showentry?ID=epub-wu-01_8cb

See Also

hitro.new and ur for replacement.