Learn R Programming

Runuran (version 0.5)

urlogarithmic: UNU.RAN Logarithmic random variate generator

Description

UNU.RAN random variate generator for the Logarithmic distribution with shape parameter shape. It also allows sampling from the truncated distribution.

Usage

urlogarithmic(n, shape, lb = 1, ub = Inf)

Arguments

n
size of required sample.
shape
shape parameter. Must be between 0 and 1.
lb
lower bound of (truncated) distribution.
ub
upper bound of (truncated) distribution.

Details

The Logarithmic distribution with parameters shape $= \theta$ has density $$f(x) = -\log(1-\theta) \theta^x / x$$ for $x = 1, 2, \ldots$ and $0 < \theta < 1$.

The generation algorithm uses guide table based inversion when the tails are not too heavy and method @code{"DARI"} otherwise. The parameters lb and ub can be used to generate variates from the Logarithmic distribution truncated to the interval (lb,ub).

References

W. H"ormann, J. Leydold, and G. Derflinger (2004): Automatic Nonuniform Random Variate Generation. Springer-Verlag, Berlin Heidelberg.

N.L. Johnson, S. Kotz, and A.W. Kemp (1992): Univariate Discrete Distributions, 2nd edition. John Wiley & Sons, Inc., New York. Chap.7, p.285.

See Also

runif and .Random.seed about random number generation and unuran for the UNU.RAN class.

Examples

Run this code
## Create a sample of size 1000
x <- urlogarithmic(n=1000,shape=0.3)

Run the code above in your browser using DataLab