UNU.RAN random variate generator for the Planck distribution with
shape parameter a.
It also allows sampling from the truncated distribution.
Usage
urplanck(n, a, lb = 1.e-12, ub = Inf)
Arguments
n
size of required sample.
a
(strictly positive) shape parameter.
lb
lower bound of (truncated) distribution.
ub
upper bound of (truncated) distribution.
Details
The Planck distribution with parameters a
has density proportional to
$$f(x) \sim \frac{x^a}{\exp(x)-1}$$
for $x \ge 0$ and $a\ge 1$.
The generation algorithm uses transformed density rejection "TDR". The
parameters lb and ub can be used to generate variates from
the Planck distribution truncated to the interval (lb,ub).
References
W. H"ormann, J. Leydold, and G. Derflinger (2004):
Automatic Nonuniform Random Variate Generation.
Springer-Verlag, Berlin Heidelberg
See Also
runif and .Random.seed about random number
generation and unuran for the UNU.RAN class.