urtdr: UNU.RAN transformend density rejection generator
Description
UNU.RAN random variate generator for continuous distributions with
given probability density function (PDF).
It is based on the Transformed Density Rejection method (TDR). [ Deprecated.
Use tdr.new instead. ]
Usage
urtdr(n, pdf, dpdf=NULL, lb=-Inf, ub=Inf, islog=TRUE, ...)
Arguments
n
size of required sample.
pdf
probability density function. (Rfunction)
dpdf
derivative of the pdf. (Rfunction)
islog
whether the pdf is given by tits logarithm (the
dpdf is then the derivative of the logarithm). (boolean)
lb, ub
lower and upper bound of domain. (numeric)
...
(optional) arguments for pdf
Details
This method is deprecated. Please use tdr.new
together with ur instead.
For further details see tdr.new.References
W. H"ormann, J. Leydold, and G. Derflinger (2004):
Automatic Nonuniform Random Variate Generation.
Springer-Verlag, Berlin Heidelberg.