uqlb and ub, i.e., these calls also allow to
draw samples from truncated distributions: ur...(n, distribution parameters, lb , ub)
Compared to the corresponding Rfunctions these ur functions
have a different behavior:
ur functions are often much faster for large
samples (e.g., a factor of about 5 for the $t$ distribution).
For small samples they are slow.}
ur functions allow to sample from truncated
versions of the original distributions. Therefore the arguments
lb (lower border) and ub (upper border) are
available for all these functions.}
ur functions are based on fast numerical
inversion algorithms. This is important for example for generating
order statistics or random vectors from copulas.}
ur functions do not allow vectors as
arguments (to be more precise: they only use the first element of
the vector).}urbeta ... Beta
urburr ... Burr
urcauchy ... Cauchy
urchi ... Chi
urchisq ... Chi-square
urexp ... Exponential
urextremeI ... Gumbel (extreme value type I)
urextremeII ... Frechet (extreme value type II)
urf ... F
urgamma ... Gamma
urgig ... GIG (generalized inverse Gaussian)
urhyperbolic ... Hyperbolic
urlaplace ... Laplace
urlnorm ... Log-Normal
urlogis ... Logistic
urlomax ... Lomax
urnorm ... Normal (Gaussian)
urpareto ... Pareto (of first kind)
urplanck ... Planck
urpowerexp ... Powerexponential (Subbotin)
urrayleigh ... Rayleigh
urt ... t (Student)
urtriang ... Triangular
urweibull ... Weibullurbinom ... Binomial
urgeom ... Geometric
urhyper ... Hypergeometric
urlogarithmic ... Logarithmic
urnbinom ... Negative Binomial
urpois ... Poissonunuran.cont.new ... continuous distributions
unuran.discr.new ... discrete distributions
unuran.cmv.new ... multivariate continuous distributionsur ... draw sample
uq ... compute quantile (inverse CDF)
unuran.details ... show unuran objectunuran . These can then
be used to draw samples from the desired distribution by means of
function ur.
Methods that implement an inversion method can also be
used for quantile function uq.
Currently the following methods are available by such functions.
Continuous Univariate Distributions:
ars.new ... Adaptive Rejection Sampling
itdr.new ... Inverse Transformed Density Rejection
pinv.new ... Polynomial interpolation of INVerse CDF
srou.new ... Simple Ratio-Of-Uniforms method
tdr.new ... Transformed Density Rejection
}
Discrete Distributions:
dari.new ... Discrete Automatic Rejection Inversion
dau.new ... Alias-Urn Method
dgt.new ... Guide-Table Method for discrete inversion
}
Multivariate Distributions:
hitro.new ... Hit-and-Run with Ratio-of-Uniforms method
vnrou.new ... Multivariate Naive Ratio-Of-Uniforms method
}unuran.distr object that contains
all required information about the target distribution.
We have three types of distribuions:}.Random.seed and can be controlled by the
R functions RNGkind and set.seed.unuran objects cannot be saved and restored in later Rsessions, nor is it possible to copy such objects to different nodes
in a computer cluster. However, unuran objects for some generation methods can be
unuran.packed.
Then these objects can be handled like any other Robject
(and thus saved and restored).
All other objects must be newly created in a new Rsession!
(Using a restored object does not work as the unuran is then
broken.)
G.~Tirler and J.~Leydold (2003): Automatic Nonuniform Random Variate Generation in R. In: K.~Hornik and F.~Leisch, Proceedings of the 3rd International Workshop on Distributed Statistical Computing (DSC~2003), March 20--22, Vienna, Austria.
unuran ,
unuran.distr ,
unuran.cont ,
unuran.discr ,
unuran .