Learn R Programming

Runuran (version 0.10.1)

unuran-class: Class "unuran" -- Universal Non-Uniform RANdom variate generators

Description

The class unuran provides an interface to the UNU.RAN library for universal non-uniform random number generators. It uses the Rbuilt-in uniform random number generator. [Advanced] -- UNU.RAN generator object.

Arguments

Objects from the Class

Objects can be created by calls of the form new("unuran", distribution, method).

  • distribution:
{A character string that describes the target distribution (see UNU.RAN User Manual) or one of the S4 classes unuran.cont, unuran.discr, or unuran.cmv that holds information about the distribution.} method:{A character string that describes the chosen generation method, see UNU.RAN User Manual. If omitted method "auto" (automatic) is used.}

Warning

unuran objects cannot be saved and restored in later Rsessions, nor is it possible to copy such objects to different nodes in a computer cluster.

However, unuran objects for some generation methods can be packed, see unuran.packed. Then these objects can be handled like any other Robject (and thus saved and restored).

All other objects must be newly created in a new Rsession! (Using a restored object does not work as the unuran is then broken.)

References

J. Leydold and W. H"ormann (2000-2007): UNU.RAN User Manual, see http://statmath.wu-wien.ac.at/unuran/. W. H"ormann, J. Leydold, and G. Derflinger (2004): Automatic Nonuniform Random Variate Generation. Springer-Verlag, Berlin Heidelberg

G. Tirler and J. Leydold (2003): Automatic Nonuniform Random Variate Generation in R. In: K.~Hornik and F.~Leisch, Proceedings of the 3rd International Workshop on Distributed Statistical Computing (DSC~2003), March 20--22, Vienna, Austria.

See Also

unuran.new and ur for faster creation and sampling routines, unuran.details for a more verbose version of show.

unuran.packed allows to pack some unuran objects. For distribution objects see unuran.cont, unuran.discr, and unuran.cmv.