Learn R Programming

Runuran (version 0.5)

unuran.cmv-class: Experimental class "unuran.cmv"

Description

The class "unuran.cmv" provides am interface to UNU.RAN objects for continuous multivariate distributions. The interface might be changed in future releases. Do not use unnamed arguments!

Arguments

Details

Create a new instance of an "unuran.cmv" object using

new ("unuran.cmv", dim=1, pdf=NULL, mode=NULL).

[object Object],[object Object],[object Object]

The user is responsible that the given informations are consistent. It depends on the chosen method which information must be given / are used.

References

J. Leydold and W. H"ormann (2000-2007): UNU.RAN User Manual, see http://statmath.wu-wien.ac.at/unuran/.

See Also

unuran, unuran.new.

Examples

Run this code
## Create discrete distribution with given probability density function
mvpdf <- function (x) { exp(-sum(x^2)) }
mvdist <- new("unuran.cmv", dim=2, pdf=mvpdf)
## Make generator (using method HITRO)
mvunr <- unuran.new(mvdist, "hitro")
## Draw sample of size 100
x <- unuran.sample(mvunr, 100)

Run the code above in your browser using DataLab